@@ -6,7 +6,7 @@
 %%% Created : 29 Aug 2010 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2016 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2017 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -28,9 +28,12 @@
 -behaviour(?GEN_SERVER).
 
 %% API
+-export([start/0, stop/0]).
 -export([start_link/4, new/2, delete/1, delete/3, lookup/3,
 	 insert/4, info/2, tab2list/1, setopts/2,
-	 dirty_lookup/3, dirty_insert/4, dirty_delete/3,
+	 dirty_lookup/3,
+         dirty_insert/4, dirty_insert/3, dirty_dist_insert/4,
+         dirty_delete/3, dirty_delete/2, dirty_dist_delete/3,
 	 all/0, clean/1]).
 
 %% gen_server callbacks
@@ -64,6 +67,12 @@
 %%====================================================================
 %% API
 %%====================================================================
+start() ->
+    application:start(?MODULE).
+
+stop() ->
+    application:stop(?MODULE).
+
 start_link(Proc, Tab, Opts, Owner) ->
     ?GEN_SERVER:start_link(
       {local, Proc}, ?MODULE, [Tab, Opts, get_proc_num(), Owner], []).
@@ -114,6 +123,17 @@ dirty_delete(Tab, Key, F) ->
     ?GEN_SERVER:call(
        get_proc_by_hash(Tab, Key), {cache_delete, Key}, ?CALL_TIMEOUT).
 
+dirty_delete(Tab, Key) ->
+    ?GEN_SERVER:call(
+       get_proc_by_hash(Tab, Key), {cache_delete, Key}, ?CALL_TIMEOUT).
+
+dirty_dist_delete(Tab, Key, F) ->
+    F(),
+    rpc:eval_everywhere(
+      cache_tab_app:get_nodes() -- [node()],
+      ?MODULE, dirty_delete, [Tab, Key]),
+    dirty_delete(Tab, Key).
+
 lookup(Tab, Key, F) ->
     ?GEN_SERVER:call(
        get_proc_by_hash(Tab, Key), {lookup, Key, F}, ?CALL_TIMEOUT).
@@ -146,6 +166,17 @@ dirty_insert(Tab, Key, Val, F) ->
     ?GEN_SERVER:call(
        get_proc_by_hash(Tab, Key), {cache_insert, Key, Val}, ?CALL_TIMEOUT).
 
+dirty_insert(Tab, Key, Val) ->
+    ?GEN_SERVER:call(
+       get_proc_by_hash(Tab, Key), {cache_insert, Key, Val}, ?CALL_TIMEOUT).
+
+dirty_dist_insert(Tab, Key, Val, F) ->
+    F(),
+    rpc:eval_everywhere(
+      cache_tab_app:get_nodes() -- [node()],
+      ?MODULE, dirty_insert, [Tab, Key, Val]),
+    dirty_insert(Tab, Key, Val).
+
 info(Tab, Info) ->
     case lists:map(
 	   fun(Proc) ->
@@ -402,8 +433,7 @@ get_all_procs(Tab) ->
     [get_proc(Tab, N) || N <- lists:seq(1, get_proc_num())].
 
 now_priority() ->
-    {MSec, Sec, USec} = now(),
-    -((MSec*1000000 + Sec)*1000000 + USec).
+    -p1_time_compat:system_time(micro_seconds).
 
 clean_priority(LifeTime) ->
     if is_integer(LifeTime) ->
