@@ -6,7 +6,7 @@
 %%% Created : 8 May 2013 by Evgeniy Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2016 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2017 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -26,7 +26,11 @@
 -behaviour(application).
 
 %% Application callbacks
--export([start/2, stop/1]).
+-export([start/2, stop/1, get_nodes/0]).
+
+-define(PG, cache_tab).
+
+-include("ets_cache.hrl").
 
 %%%===================================================================
 %%% Application callbacks
@@ -51,6 +55,10 @@
 start(_StartType, _StartArgs) ->
     case cache_tab_sup:start_link() of
         {ok, Pid} ->
+            pg2:create(?PG),
+            pg2:join(?PG, Pid),
+	    application:start(p1_utils),
+	    init_ets_cache_options(),
             {ok, Pid};
         Error ->
             Error
@@ -69,6 +77,14 @@ start(_StartType, _StartArgs) ->
 stop(_State) ->
     ok.
 
+get_nodes() ->
+    [node(P) || P <- pg2:get_members(?PG)].
+
 %%%===================================================================
 %%% Internal functions
 %%%===================================================================
+init_ets_cache_options() ->
+    p1_options:start_link(ets_cache_options),
+    p1_options:insert(ets_cache_options, max_size, global, ?DEFAULT_MAX_SIZE),
+    p1_options:insert(ets_cache_options, life_time, global, ?DEFAULT_LIFE_TIME),
+    p1_options:insert(ets_cache_options, cache_missed, global, ?DEFAULT_CACHE_MISSED).
